pub struct Context {
pub req: Request,
/* private fields */
}Expand description
Context holds request data and provides response building methods
Fields
req: RequestImplementations
Sourceimpl Context
impl Context
Sourcepub async fn new(req: HyperRequest<Incoming>, params: Params) -> Result<Self>
pub async fn new(req: HyperRequest<Incoming>, params: Params) -> Result<Self>
Create a new context from a request and params
Sourcepub async fn set(&self, key: impl Into<String>, value: impl Into<String>)
pub async fn set(&self, key: impl Into<String>, value: impl Into<String>)
Set a value in the context state (shared between middleware)